@@ -805,9 +805,11 @@ setMethodS3("getNumerics", "Arguments", function(static, x, range=NULL, asMode=N
     throw(sprintf("Argument 'range' is not ordered: c(%s,%s)", range[1], range[2]));
   }
 
-  withCallingHandlers({
+  # Suppress warnings when there are no finite values in x.
+  suppressWarnings({
     xrange <- range(x, na.rm=TRUE);
-  }, warnings=function(warn) {})
+  })
+
   if (xrange[1] < range[1] || xrange[2] > range[2]) {
     xrange <- as.character(xrange);
     range <- as.character(range);
@@ -1294,6 +1296,9 @@ setMethodS3("getInstanceOf", "Arguments", function(static, object, class, coerce
 
 ############################################################################
 # HISTORY:
+# 2013-11-15
+# o CLEANUP: Arguments$getNumerics(NA, range=c(0,1)) no longer gives
+#   warnings on "no non-missing arguments to min()" etc.
 # 2013-08-26
 # o CLEANUP: Arguments$getReadablePathnames(files, paths=NULL) no longer
 #   warns about "rep(paths, length.out = nbrOfFiles) : 'x' is NULL so
