@@ -26,15 +26,19 @@
 #
 # @keyword utilities
 # @keyword package
-#*/########################################################################### 
+#*/###########################################################################
 setMethodS3("isPackageInstalled", "default", function(package, ...) {
-  path <- system.file(package=package);
+  suppressWarnings({
+    path <- system.file(package=package);
+  });
   (path != "");
 })
 
 
 ############################################################################
 # HISTORY:
+# 2013-08-30
+# o Now isPackageInstalled() suppresses warnings.
 # 2009-01-11
 # o Created.
 ############################################################################
